import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleOrdinal,
  schemeCategory10
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { scatterplot } from './scatterplot';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const margin = { top: 60, right: 40, bottom: 88, left: 150 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const g = svg.append('g').attr('transform', `translate(${margin.left},${margin.top})`);
const colorLegendG = svg.append('g');

const title = 'Calories vs Protein';
  
const color = scaleOrdinal(schemeCategory10);
  
const xValue = d => d.Calories;
const xAxisLabel = 'Calories';
  
const yValue = d => d.Protein;
const circleRadius = 10;
const yAxisLabel = 'Protein';

let selectedCategory = null;
let menuItems;

const colorValue = data => data.Category;

const onClick = d => {
    selectedCategory = d;
  	console.log(selectedCategory);
  	render();
  };

loadAndProcessData().then(data => {
	menuItems = data;
  	render();
});

const render = () => {
  
  g.call(scatterplot, {
  	xAxisLabel,
    yAxisLabel,
    circleRadius,
    margin,
    innerWidth,
    innerHeight,
    menuItems,
    color,
    colorValue,
    selectedCategory,
    title
  });
  
  
/*  colorLegendG.call(colorLegend, {
	color,
    width,
    selectedCategory,
    onClick
  });
};*/