import {
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
} from 'd3';

export const scatterplot = (selection, props) => {

  const {
    xAxisLabel,
    yAxisLabel,
    circleRadius,
    margin,
    innerWidth,
    innerHeight,
    menuItems,
    color,
    colorValue,
    selectedCategory,
    title
  } = props;

  const xValue = d => d.Calories;

  const yValue = d => d.Protein;

  const xScale = scaleLinear()
    .domain(extent(menuItems, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(menuItems, yValue))
    .range([innerHeight, 0])
    .nice();

  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);

  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);

  const yAxisG = selection.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();

  yAxisG.append('text')
    .attr('class', 'axis-label')
    .attr('y', -93)
    .attr('x', -innerHeight / 2)
    .attr('fill', 'black')
    .attr('transform', `rotate(-90)`)
    .attr('text-anchor', 'middle')
    .text(yAxisLabel);

  const xAxisG = selection.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);

  xAxisG.select('.domain').remove();

  xAxisG.append('text')
    .attr('class', 'axis-label')
    .attr('y', 75)
    .attr('x', innerWidth / 2)
    .attr('fill', 'black')
    .text(xAxisLabel);

  var tooltip = d3.select("body").append("div")
    .attr("class", "tooltip")
    .style("opacity", 0);

  // tooltip mouseover event handler
  var tipMouseover = function (d) {
    var html = d.Item + "<br/>" +
      "<span style='color:" + color(colorValue(d)) + ";'>" + d.Category + "</span><br/>" +
      "<b>" + d.Calories + "</b> calories, <b/>" + d.Protein + "</b> Protein(g)";;
    tooltip.html(html)
      .style("left", (d3.event.pageX + 15) + "px")
      .style("top", (d3.event.pageY - 28) + "px")
      .transition()
      .duration(200) // ms
      .style("opacity", .9) // started as 0!
  };
  // tooltip mouseout event handler
  var tipMouseout = function (d) {
    tooltip.transition()
      .duration(300) // ms
      .style("opacity", 0);
  };

  
  let circles = selection.selectAll('circle').data(menuItems);
  let circlesEnter = circles.enter().append('circle')
    .attr('class', 'circle')
    .attr('cy', d => yScale(yValue(d)))
    .attr('cx', d => xScale(xValue(d)))
    .attr('r', circleRadius)
    .attr('fill', d => color(colorValue(d)))
    .on('mouseover', tipMouseover)
    .on('mouseout', tipMouseout);

  circles
    .merge(circlesEnter)
    .attr('opacity', d =>
      (selectedCategory === colorValue(d))
        ? 1
        : 0.05
    );

  selection.append('text')
    .attr('class', 'title')
    .attr('y', -10)
    .text(title);
  
};